/*
 *      main.c
 *
 *      Copyright 2016-2018 Alex <alex@linuxonly.ru>
 *
 *      This program is free software: you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtk/gtk.h>
#include <gst/gst.h>
#include <libintl.h>
#include <locale.h>
#include <stdlib.h>
#include <glib/gprintf.h>

#include "lark-app.h"
#include "../resources.h"

int main (int argc, char *argv[])
{
	GOptionContext *option_context;
	gboolean version = FALSE;
	gchar **filenames = NULL;
	GError *error = NULL;
	GOptionEntry option_entries[] = {
		{ "version",           'v', 0, G_OPTION_ARG_NONE,           &version,   _("Show version number and exit"),                         NULL },
		{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, _("Special option that collects any remaining arguments"), NULL },
		{ NULL, 0,   0, 0, NULL, NULL, NULL }
	};
	
	/*Gettext initialization*/
	setlocale(LC_ALL, "");
	bindtextdomain(RESOURCE_LOCALE_DOMAIN, RESOURCE_LOCALE_DIR);
	bind_textdomain_codeset(RESOURCE_LOCALE_DOMAIN, "UTF-8");
	textdomain(RESOURCE_LOCALE_DOMAIN);
	
	/*Application name*/
	g_set_application_name(_(RESOURCE_NAME));
	
	/*Initialize GStreamer*/
	gst_init(&argc, &argv);
	
	/*Parse context*/
	option_context = g_option_context_new(_("[BOOK FILE]"));
	g_option_context_add_main_entries(option_context, option_entries, RESOURCE_LOCALE_DOMAIN);
	g_option_context_add_group(option_context, gtk_get_option_group(FALSE));
	g_option_context_set_translation_domain(option_context, RESOURCE_LOCALE_DOMAIN);
	
	/*Parse command line options*/
	if (!g_option_context_parse(option_context, &argc, &argv, &error)) {
		g_printf("%s\n", error->message);
		g_error_free(error);
		g_option_context_free(option_context);
		return EXIT_FAILURE;
	}
	g_option_context_free(option_context);
	
	/*Show version and exit*/
	if (version) {
		g_printf("%s %s\n", RESOURCE_NAME, RESOURCE_VERSION);
		return EXIT_SUCCESS;
	}
	
	/*Run application*/
	return g_application_run(G_APPLICATION(lark_app_new(filenames)), argc, argv);
}
